import { __decorate } from 'tslib';
import { ɵɵdefineInjectable, Injectable, Component, NgModule } from '@angular/core';
import { BehaviorSubject } from 'rxjs';
import { FormsModule } from '@angular/forms';
import { CommonModule } from '@angular/common';

let ThemeService = class ThemeService {
    constructor() {
        var _a;
        this._theme = new BehaviorSubject(null);
        this.loadHandler = () => typeof localStorage !== 'undefined' ? localStorage.getItem('theme') : null;
        this.saveHandler = theme => {
            if (typeof localStorage === 'undefined') {
                return;
            }
            if (theme) {
                localStorage.setItem('theme', theme);
            }
            else {
                localStorage.removeItem('theme');
            }
        };
        this._theme.next((_a = this.savedTheme) !== null && _a !== void 0 ? _a : this.detectedTheme);
        this._theme.subscribe(theme => {
            if (theme) {
                document.body.setAttribute('theme', theme);
            }
            else {
                document.body.removeAttribute('theme');
            }
        });
        this._theme.subscribe(theme => this.savedTheme = theme);
    }
    get theme$() {
        return this._theme;
    }
    get detectedTheme() {
        return typeof window !== 'undefined' && window.matchMedia('(prefers-color-scheme: dark)').matches ? 'dark' : 'light';
    }
    get theme() {
        return this._theme.getValue();
    }
    set theme(value) {
        this._theme.next(value);
    }
    get savedTheme() {
        return this.loadHandler();
    }
    set savedTheme(theme) {
        this.saveHandler(theme);
    }
};
ThemeService.ɵprov = ɵɵdefineInjectable({ factory: function ThemeService_Factory() { return new ThemeService(); }, token: ThemeService, providedIn: "root" });
ThemeService = __decorate([
    Injectable({
        providedIn: 'root'
    })
], ThemeService);

let DarkSwitchComponent = class DarkSwitchComponent {
    constructor(themeService) {
        this.themeService = themeService;
    }
    ngOnInit() {
        this.theme$ = this.themeService.theme$;
    }
};
DarkSwitchComponent.ctorParameters = () => [
    { type: ThemeService }
];
DarkSwitchComponent = __decorate([
    Component({
        selector: 'ng-bootstrap-darkmode-switch',
        template: "<div class=\"custom-control custom-switch\">\n  <input type=\"checkbox\" class=\"custom-control-input\" id=\"darkModeSwitch\"\n         [ngModel]=\"(theme$ | async) === 'dark'\" (ngModelChange)=\"theme$.next($event ? 'dark' : 'light')\">\n  <label class=\"custom-control-label\" for=\"darkModeSwitch\">\n    Dark Mode\n  </label>\n</div>\n",
        styles: [""]
    })
], DarkSwitchComponent);

let NgBootstrapDarkmodeModule = class NgBootstrapDarkmodeModule {
};
NgBootstrapDarkmodeModule = __decorate([
    NgModule({
        declarations: [
            DarkSwitchComponent,
        ],
        imports: [
            CommonModule,
            FormsModule,
        ],
        exports: [
            DarkSwitchComponent,
        ]
    })
], NgBootstrapDarkmodeModule);

/*
 * Public API Surface of ng-bootstrap-darkmode
 */

/**
 * Generated bundle index. Do not edit.
 */

export { DarkSwitchComponent, NgBootstrapDarkmodeModule, ThemeService };
//# sourceMappingURL=ng-bootstrap-darkmode.js.map
